intelmq.bots.experts.wait package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.wait package

## Submodules

## intelmq.bots.experts.wait.expert module

Created on Tue Jan 23 15:25:58 2018

@author: sebastian

`intelmq.bots.experts.wait.expert.` `BOT`

  alias of `intelmq.bots.experts.wait.expert.WaitExpertBot`

class `intelmq.bots.experts.wait.expert.` `WaitExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Wait for a some time or until a queue size is lower than a given number

  `connect_redis`()
  `init`()
  `process`()
  `queue_db`: int = 2
  `queue_host`: str = 'localhost'
  `queue_name`: str = None
  `queue_password`: str = None
  `queue_polling_interval`: float = 0.05
  `queue_port`: int = 6379
  `queue_size`: int = 0
  `sleep_time`: int = None

## Module contents